@@ -8,33 +8,29 @@ class ApplicationResource(BaseResource):
     def __init__(self, configuration: Configuration):
         super().__init__("applications", configuration)
 
-    def create(self, request: Union[CreateIndividualApplicationRequest, CreateBusinessApplicationRequest]) -> Union[UnitResponse[ApplicationDTO], UnitError]:
+    def create(self, request: CreateApplicationRequest) -> Union[UnitResponse[ApplicationDTO], UnitError]:
         payload = request.to_json_api()
         response = super().post_create(self.resource, payload)
 
-        if response.ok:
+        if super().is_20x(response.status_code):
             data = response.json().get("data")
             included = response.json().get("included")
-            if data["type"] == "individualApplication":
-                return UnitResponse[IndividualApplicationDTO](DtoDecoder.decode(data), DtoDecoder.decode(included))
-            else:
-                return UnitResponse[BusinessApplicationDTO](DtoDecoder.decode(data), DtoDecoder.decode(included))
+            return UnitResponse[ApplicationDTO](DtoDecoder.decode(data), DtoDecoder.decode(included))
         else:
             return UnitError.from_json_api(response.json())
 
     def list(self, params: ListApplicationParams = None) -> Union[UnitResponse[List[ApplicationDTO]], UnitError]:
         params = params or ListApplicationParams()
         response = super().get(self.resource, params.to_dict())
-        if response.status_code == 200:
+        if super().is_20x(response.status_code):
             data = response.json().get("data")
-            included = response.json().get("included")
             return UnitResponse[ApplicationDTO](DtoDecoder.decode(data), None)
         else:
             return UnitError.from_json_api(response.json())
 
     def get(self, application_id: str) -> Union[UnitResponse[ApplicationDTO], UnitError]:
         response = super().get(f"{self.resource}/{application_id}")
-        if response.status_code == 200:
+        if super().is_20x(response.status_code):
             data = response.json().get("data")
             included = response.json().get("included")
             return UnitResponse[ApplicationDTO](DtoDecoder.decode(data), DtoDecoder.decode(included))
@@ -56,13 +52,13 @@ class ApplicationResource(BaseResource):
                 headers = {"Content-Type": "application/pdf"}
 
         response = super().put(url, request.file, headers)
-        if response.status_code == 200:
+        if super().is_20x(response.status_code):
             data = response.json().get("data")
             return UnitResponse[ApplicationDocumentDTO](DtoDecoder.decode(data), None)
         else:
             return UnitError.from_json_api(response.json())
 
-    def update(self, request: PatchApplicationRequest) -> Union[UnitResponse[ApplicationDTO], UnitError]:
+    def update(self, request: UnionPatchApplicationRequest) -> Union[UnitResponse[ApplicationDTO], UnitError]:
         payload = request.to_json_api()
         response = super().patch(f"{self.resource}/{request.application_id}", payload)
         if super().is_20x(response.status_code):
@@ -71,6 +67,15 @@ class ApplicationResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
+    def update_business_beneficial_owner(self, request: PatchBusinessBeneficialOwnerRequest) -> Union[UnitResponse[BeneficialOwnerDTO], UnitError]:
+        payload = request.to_json_api()
+        response = super().patch(f"beneficial-owner/{request.beneficial_owner_id}", payload)
+        if super().is_20x(response.status_code):
+            data = response.json().get("data")
+            return UnitResponse[BeneficialOwnerDTO](DtoDecoder.decode(data), None)
+        else:
+            return UnitError.from_json_api(response.json())
+
     def cancel(self, request: CancelApplicationRequest) -> Union[UnitResponse[ApplicationDTO], UnitError]:
         payload = request.to_json_api()
         response = super().post(f"{self.resource}/{request.application_id}/cancel", payload)
